panorama
========

Create panorama in one run. Uses hugin for the real work.

Installation
------------
.. code-block:: shell

    pip install panorama

Usage
-----
.. code-block:: shell

    create-panorama-from-jpg-files-in-directory file_containing_jpg_files
